@@ -4,9 +4,9 @@
 //#include <windows.h>		// Header File For Windows
 #include <time.h>
 //#include "SDL/SDL.h"
-#include <GL/gl.h>			// Header File For The OpenGL32 Library
-#include <GL/glu.h>			// Header File For The GLu32 Library
-#include <GL/glext.h>		// Header File For The Glaux Library
+//#include <GL/gl.h>			// Header File For The OpenGL32 Library
+//#include <GL/glu.h>			// Header File For The GLu32 Library
+//#include <GL/glext.h>		// Header File For The Glaux Library
 
 // Routine with the static elements
 #define INCL_OBJECTS
@@ -372,47 +372,13 @@ public:
 		pdelta.push_back(pmax[2] - pmin[2]);
 	}
 	
-	GLfloat init_x;
-	GLfloat init_y;
-	GLfloat init_z;
-	GLfloat delta_step;
-	GLfloat delta_stepx;
-	GLfloat	rtri;				// Angle of rotation in Y axis
-	GLfloat	rtrix;				// Angle of rotation in X axis
-
 	ResultAg()
 	{
 
-		init_x = 0.0f;
-		init_y = 0.0f;
-		init_z = -22.0f;
-		rtri = 60;				// Angle of rotation in Y axis 
-		rtrix = 0;				// Angle of rotation in X axis 
-		delta_step = 0.3f;
-		delta_stepx = 0.0f;
 	}
 
 	//LRESULT	CALLBACK WndProc(HWND, UINT, WPARAM, LPARAM);	// Declaration For WndProc
 
-	static GLvoid ReSizeGLScene(GLsizei width, GLsizei height)		// Resize And Initialize The GL Window
-	{
-		if (height==0)										// Prevent A Divide By Zero By
-		{
-			height=1;										// Making Height Equal One
-		}
-
-		glViewport(0,0,width,height);						// Reset The Current Viewport
-
-		glMatrixMode(GL_PROJECTION);						// Select The Projection Matrix
-		glLoadIdentity();									// Reset The Projection Matrix
-
-		// Calculate The Aspect Ratio Of The Window
-		gluPerspective(45.0f,(GLfloat)width/(GLfloat)height,0.1f,100.0f);
-
-		glMatrixMode(GL_MODELVIEW);							// Select The Modelview Matrix
-		glLoadIdentity();									// Reset The Modelview Matrix
-	}
-
 	
 private:
 	// technical variables
@@ -422,265 +388,6 @@ private:
 public:
 
 
-	int DrawGLScene()									// Here's Where We Do All The Drawing
-	{
-		glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);	// Clear Screen And Depth Buffer
-		glClearColor(1.0f,1.0f,1.0f,1.0f);                  // White background color
-		
-		//init_x = 0.0f;
-		//init_y = 0.0f;
-		//init_z = -10.0f;
-
-		// ********************* Display points from the data cloud **************************
-
-		glLoadIdentity();									// Reset The Current Modelview Matrix
-		glTranslatef(init_x, init_y, init_z);				// Move Left 1.5 Units And Into The Screen 6.0
-		glRotatef(rtri,0.0f,1.0f,0.0f);						// Rotate The Triangle On The Y axis 
-		glRotatef(rtrix,1.0f,0.0f,0.0f);						// Rotate The Triangle On The Y axis 
-		glBegin(GL_TRIANGLES);								// Start Drawing A Triangle
-		glColor3f(1.0f,0.0f,0.0f);
-
-		vector<Point>::iterator pointit;
-
-		GLfloat fat = 0.1f;
-
-		for(pointit = this->data_cloud.begin(); pointit != this->data_cloud.end(); pointit++)
-		{
-				glVertex3f( pointit->coord[0] + fat,pointit->coord[1],pointit->coord[2]);					
-				glVertex3f( pointit->coord[0] - fat,pointit->coord[1] + fat,pointit->coord[2]);					
-				glVertex3f( pointit->coord[0] - fat,pointit->coord[1] - fat,pointit->coord[2] - fat);					
-
-				glVertex3f( pointit->coord[0] + fat,pointit->coord[1],pointit->coord[2]);					
-				glVertex3f( pointit->coord[0] - fat,pointit->coord[1] + fat,pointit->coord[2]);					
-				glVertex3f( pointit->coord[0] - fat,pointit->coord[1] - fat,pointit->coord[2] + fat);					
-				
-				glVertex3f( pointit->coord[0] + fat,pointit->coord[1],pointit->coord[2]);					
-				glVertex3f( pointit->coord[0] - fat,pointit->coord[1] - fat,pointit->coord[2] - fat);					
-				glVertex3f( pointit->coord[0] - fat,pointit->coord[1] - fat,pointit->coord[2] + fat);					
-
-				glVertex3f( pointit->coord[0] - fat,pointit->coord[1] + fat,pointit->coord[2]);					
-				glVertex3f( pointit->coord[0] - fat,pointit->coord[1] - fat,pointit->coord[2] - fat);					
-				glVertex3f( pointit->coord[0] - fat,pointit->coord[1] - fat,pointit->coord[2] + fat);					
-		}
-
-		glEnd();											// Done Drawing the points
-
-		// ***********************************************************************************
-
-
-		// ********************* Display the trimmed region **********************************
-
-		glLoadIdentity();									// Reset The Current Modelview Matrix
-		glTranslatef(init_x, init_y, init_z);				// Move Left 1.5 Units And Into The Screen 6.0
-		glRotatef(rtri,0.0f,1.0f,0.0f);						// Rotate The Triangle On The Y axis 
-		glRotatef(rtrix,1.0f,0.0f,0.0f);						// Rotate The Triangle On The Y axis 
-		glBegin(GL_TRIANGLES);								// Start Drawing A Triangle
-		
-		list<Facet>::iterator facetit;
-		int stop = 0;
-		flborder++; 
-		if(flborder > this->trimmed_region.size()) 
-		{
-			flborder = 1;
-		}
-
-		for(facetit = this->trimmed_region.begin(); facetit != this->trimmed_region.end(); facetit++)
-		{			
-			if(facetit->normalvec.coord[0]>0 || facetit->normalvec.coord[1]>0 || facetit->normalvec.coord[2]>0)
-				continue;
-
-			if( !facetit->truncated /*&&  ++stop<flborder*/  )
-			{
-				
-				float peak = max(fabs(facetit->normalvec.coord[0]), max(fabs(facetit->normalvec.coord[1]), fabs(facetit->normalvec.coord[2])));
-				float gr_sigma = 2;
-				float gr_mu    = 0.5f;
-				float colx = -facetit->normalvec.coord[0] / (gr_sigma * peak) + gr_mu;
-				float coly = -facetit->normalvec.coord[1] / (gr_sigma * peak) + gr_mu;
-				float colz = -facetit->normalvec.coord[2] / (gr_sigma * peak) + gr_mu;
-				glColor3f(colx, coly, colz);
-
-				list<ExtremePoint>::iterator expointit;
-				
-				expointit = facetit->nodes.begin();
-				//glColor3f((expointit->coord[0] - pmin[0])/pdelta[0],
-				//		  (expointit->coord[1] - pmin[1])/pdelta[1],
-				//		  (expointit->coord[2] - pmin[2])/pdelta[2]);
-				glVertex3f(expointit->coord[0],expointit->coord[1],expointit->coord[2]);		
-				
-				expointit++;
-				//glColor3f((expointit->coord[0] - pmin[0])/pdelta[0],
-				//		  (expointit->coord[1] - pmin[1])/pdelta[1],
-				//		  (expointit->coord[2] - pmin[2])/pdelta[2]);						
-				glVertex3f(expointit->coord[0],expointit->coord[1],expointit->coord[2]);					
-				
-				expointit++;
-				//glColor3f((expointit->coord[0] - pmin[0])/pdelta[0],
-				//		  (expointit->coord[1] - pmin[1])/pdelta[1],
-				//		  (expointit->coord[2] - pmin[2])/pdelta[2]);
-				glVertex3f(expointit->coord[0],expointit->coord[1],expointit->coord[2]);
-			}
-		}
-
-	
-		glEnd();											// Done Drawing the truncated faces 
-
-		
-		glLoadIdentity();									// Reset The Current Modelview Matrix
-		glTranslatef(init_x, init_y, init_z);				// Move Left 1.5 Units And Into The Screen 6.0
-		glRotatef(rtri,0.0f,1.0f,0.0f);						// Rotate The Triangle On The Y axis 
-		glRotatef(rtrix,1.0f,0.0f,0.0f);						// Rotate The Triangle On The Y axis 
-		
-		bool flash = true;
-
-		//markfirst = !markfirst;
-		//bool isfirst = true;
-		//if( ! this->trimmed_region.front().truncated)
-		//	isfirst = false;
-
-		for(facetit = this->trimmed_region.begin(); facetit != this->trimmed_region.end(); facetit++)
-		{			
-						
-			if(facetit->normalvec.coord[0]>0 || facetit->normalvec.coord[1]>0 || facetit->normalvec.coord[2]>0)
-				continue;
-
-			if( facetit->truncated /*&& ++stop<flborder*/ )
-			{
-				//flash = !flash;
-				//if(!flash) continue;
-				
-				//if(isfirst && !markfirst)
-				//	break;
-				//isfirst = false;
-
-				float peak = max(fabs(facetit->normalvec.coord[0]), max(fabs(facetit->normalvec.coord[1]), fabs(facetit->normalvec.coord[2])));
-				float gr_sigma = 2;
-				float gr_mu    = 0.5f;
-				float colx = -facetit->normalvec.coord[0] / (gr_sigma * peak) + gr_mu;
-				float coly = -facetit->normalvec.coord[1] / (gr_sigma * peak) + gr_mu;
-				float colz = -facetit->normalvec.coord[2] / (gr_sigma * peak) + gr_mu;
-
-				list<ExtremePoint>::iterator expointit;
-				list<ExtremePoint>::iterator expointitback;
-				
-				glBegin(GL_POLYGON);
-
-				glColor3f(colx, coly, colz);
-
-				for(expointit = facetit->nodes.begin(); expointit != facetit->nodes.end(); expointit++)
-				{
-
-					//glColor3f((expointit->coord[0] - pmin[0])/pdelta[0],
-					//		  (expointit->coord[1] - pmin[1])/pdelta[1],
-					//		  (expointit->coord[2] - pmin[2])/pdelta[2]);
-					glVertex3f(expointit->coord[0],expointit->coord[1],expointit->coord[2]);
-
-				}
-
-				glEnd();											// Done Drawing the truncated face
-				
-
-				glBegin(GL_POLYGON);
-				expointitback = facetit->nodes.end();
-				for(expointit = facetit->nodes.begin(); expointit != expointitback; expointit++)
-				{
-
-					expointitback--;
-					//glColor3f((expointit->coord[0] - pmin[0])/pdelta[0],
-					//		  (expointit->coord[1] - pmin[1])/pdelta[1],
-					//		  (expointit->coord[2] - pmin[2])/pdelta[2]);
-					glVertex3f(expointit->coord[0],expointit->coord[1],expointit->coord[2]);
-
-					//glColor3f((expointitback->coord[0] - pmin[0])/pdelta[0],
-					//		  (expointitback->coord[1] - pmin[1])/pdelta[1],
-					//		  (expointitback->coord[2] - pmin[2])/pdelta[2]);
-					glVertex3f(expointitback->coord[0],expointitback->coord[1],expointitback->coord[2]);
-
-				}
-				glEnd();											// Done Drawing the truncated face
-
-
-				glBegin(GL_POLYGON);
-
-				for(expointitback = facetit->nodes.end(); expointitback != facetit->nodes.begin(); expointitback--)
-				{
-					expointit = expointitback;
-					expointit--;
-
-					//glColor3f((expointit->coord[0] - pmin[0])/pdelta[0],
-					//		  (expointit->coord[1] - pmin[1])/pdelta[1],
-					//		  (expointit->coord[2] - pmin[2])/pdelta[2]);
-					glVertex3f(expointit->coord[0],expointit->coord[1],expointit->coord[2]);
-
-				}
-					
-				glEnd();											// Done Drawing the truncated face
-				
-			}
-		}
-		
-
-		// ***********************************************************************************
-		
-		
-		// ********************* Display edges of the trimmed region *************************
-
-		glLoadIdentity();									// Reset The Current Modelview Matrix
-		glTranslatef(init_x, init_y, init_z);				// Move Left 1.5 Units And Into The Screen 6.0
-		glRotatef(rtri,0.0f,1.0f,0.0f);						// Rotate The Triangle On The Y axis
-		glRotatef(rtrix,1.0f,0.0f,0.0f);						// Rotate The Triangle On The Y axis 
-		glBegin(GL_LINES);								
-		
-		glColor3f(0.4f,0.4f,0.4f);						
-		for(facetit = this->trimmed_region.begin(); facetit != this->trimmed_region.end(); facetit++)
-		{			
-			/*if( !facetit->truncated )
-			{
-				list<ExtremePoint>::iterator expointit;
-				
-				expointit = facetit->nodes.begin();
-				glVertex3f(expointit->coord[0],expointit->coord[1],expointit->coord[2]);		
-				
-				expointit++;
-				glVertex3f(expointit->coord[0],expointit->coord[1],expointit->coord[2]);					
-				glVertex3f(expointit->coord[0],expointit->coord[1],expointit->coord[2]);					
-				
-				expointit++;
-				glVertex3f(expointit->coord[0],expointit->coord[1],expointit->coord[2]);					
-				glVertex3f(expointit->coord[0],expointit->coord[1],expointit->coord[2]);
-
-				expointit = facetit->nodes.begin();
-				glVertex3f(expointit->coord[0],expointit->coord[1],expointit->coord[2]);
-			}*/
-
-			list<ExtremePoint>::iterator expointit, expointitn;
-			expointit = facetit->nodes.begin();
-			expointitn = expointit;
-			expointitn++;
-			for(; expointitn != facetit->nodes.end(); expointit++, expointitn++)
-			{
-				glVertex3f(expointit->coord[0],expointit->coord[1],expointit->coord[2]);		
-				glVertex3f(expointitn->coord[0],expointitn->coord[1],expointitn->coord[2]);					
-			}
-			expointitn = facetit->nodes.begin();
-			glVertex3f(expointit->coord[0],expointit->coord[1],expointit->coord[2]);		
-			glVertex3f(expointitn->coord[0],expointitn->coord[1],expointitn->coord[2]);					
-				
-		}
-
-		glEnd();											// Done Drawing the edges 
-
-		// ***********************************************************************************
-
-
-		rtri += delta_step;									// Increase The Rotation Variable For The Figure
-		rtrix += delta_stepx;									// Increase The Rotation Variable For The Figure
-		return 0;										// Keep Going
-	}
-
-
-
-
 	void GLSceneToExport(int _bound)									// Here's Where We Do All The Drawing
 	{
 		// Only for d=3
